function edit_CT_Tb1_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CT_Tb1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CT_Tb1 as text
%        str2double(get(hObject,'String')) returns contents of edit_CT_Tb1 as a double

    disp('edit_CT_Tb1_Callback')

end

